@@ -39,7 +39,8 @@
 #include "qownlanguagedata.h"
 
 // We enable QStringView with Qt 5.15.14
-// Note: QStringView::mid wasn't working correctly at least with 5.15.2 and 5.15.3, but 5.15.14 was fine
+// Note: QStringView::mid wasn't working correctly at least with 5.15.2
+// and 5.15.3, but 5.15.14 was fine
 #if QT_VERSION < QT_VERSION_CHECK(5, 15, 14)
 #define MH_SUBSTR(pos, len) text.midRef(pos, len)
 #else
@@ -172,7 +173,9 @@ void MarkdownHighlighter::initHighlightingRules() {
     {
         HighlightingRule rule(HighlighterState::Table);
         rule.shouldContain = QStringLiteral("|");
-        rule.pattern = QRegularExpression(QStringLiteral("^\\|.+?\\|$"));
+        // Support up to 3 spaces before the table because md4c seems to support that
+        // See https://github.com/pbek/QOwnNotes/issues/3137
+        rule.pattern = QRegularExpression(QStringLiteral("^\\s{0,3}\\|.+?\\|$"));
         _highlightingRules.append(rule);
     }
 }
@@ -461,8 +464,9 @@ static bool isParagraph(const QString &text) {
     // unordered listtextView
     if (textView.startsWith(QStringLiteral("- ")) ||
         textView.startsWith(QStringLiteral("+ ")) ||
-        textView.startsWith(QStringLiteral("*")))
+        textView.startsWith(QStringLiteral("* "))) {
         return false;
+    }
     // block quote
     if (textView.startsWith(QStringLiteral("> "))) return false;
     // atx heading
@@ -493,14 +497,20 @@ static bool isParagraph(const QString &text) {
     // ordered list
     if (textView.at(0).isDigit()) {
         int i = 1;
+        int count = 1;
         for (; i < textView.size(); ++i) {
-            if (textView[i].isDigit())
+            if (textView[i].isDigit()) {
+                count++;
                 continue;
-            else
+            } else
                 break;
         }
-        if (textView[i] == QLatin1Char('.') ||
-            textView[i] == QLatin1Char(')')) {
+
+        // ordered list marker can't be more than 9 numbers
+        if (count <= 9 && i + 1 < textView.size() &&
+            (textView[i] == QLatin1Char('.') ||
+             textView[i] == QLatin1Char(')')) &&
+            textView[i + 1] == QLatin1Char(' ')) {
             return false;
         }
     }
@@ -1830,9 +1840,10 @@ void MarkdownHighlighter::highlightLists(const QString &text) {
         int number = curPos;
         // move forward till first non-number char
         while (number < text.length() && text.at(number).isNumber()) ++number;
+        int count = number - curPos;
 
         // reached end?
-        if (number + 1 >= text.length()) return;
+        if (number + 1 >= text.length() || count > 9) return;
 
         // there should be a '.' or ')' after a number
         if ((text.at(number) == QLatin1Char('.') ||
